@@ -1,4 +1,5 @@
-package Audio::Play::#OSNAME#;
+package
+ Audio::Play::#OSNAME#;
 require Audio::Play;
 @ISA = qw(Audio::Play);
 bootstrap Audio::Play::#OSNAME# $Audio::Data::VERSION;
